char *lawyerese =
"Copyright (c) 1997 Digital Equipment Corporation. All rights reserved.\n"
"\n"
"By downloading, installing, using, modifying or distributing this software, you\n"
"agree to the following:\n"
"\n"
"1. CONDITIONS. Subject to the following conditions, you may download, install,\n"
"use, modify and distribute this software in source and binary forms:\n"
"\n"
"a) Any source code, binary code and associated documentation (including the\n"
"online manual) used, modified or distributed must reproduce and retain the above\n"
"copyright notice, this list of conditions and the following disclaimer.\n"
"\n"
"b) No right is granted to use any trade name, trademark or logo of Digital\n"
"Equipment Corporation.  Neither the ''Digital Equipment Corporation'' name nor\n"
"any trademark or logo of Digital Equipment Corporation may be used to endorse or\n"
"promote products derived from this software without the prior written permission\n"
"of Digital Equipment Corporation.\n"
"\n"
"2.  DISCLAIMER.  THIS SOFTWARE IS PROVIDED BY DIGITAL ''AS IS'' AND ANY EXPRESS\n"
"OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF\n"
"MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.IN NO EVENT\n"
"SHALL DIGITAL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,\n"
"EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT\n"
"OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS\n"
"INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN\n"
"CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING\n"
"IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY\n"
"OF SUCH DAMAGE.\n"
;
